@@ -905,6 +905,9 @@ UNSUPPORTEDOPERATION_INSTANCECHARGETYPE = 'UnsupportedOperation.InstanceChargeTy
 # 不支持混合付费模式。
 UNSUPPORTEDOPERATION_INSTANCEMIXEDPRICINGMODEL = 'UnsupportedOperation.InstanceMixedPricingModel'
 
+# 不支持混合升配和降配实例。
+UNSUPPORTEDOPERATION_INSTANCEMIXEDRESETINSTANCETYPE = 'UnsupportedOperation.InstanceMixedResetInstanceType'
+
 # 中心可用区和边缘可用区实例不能混用批量操作。
 UNSUPPORTEDOPERATION_INSTANCEMIXEDZONETYPE = 'UnsupportedOperation.InstanceMixedZoneType'
 
@@ -1016,9 +1019,6 @@ UNSUPPORTEDOPERATION_INVALIDINSTANCEWITHSWAPDISK = 'UnsupportedOperation.Invalid
 # 用户无权限操作当前实例。
 UNSUPPORTEDOPERATION_INVALIDINSTANCESOWNER = 'UnsupportedOperation.InvalidInstancesOwner'
 
-# 当前操作只支持国际版用户。
-UNSUPPORTEDOPERATION_INVALIDPERMISSIONNONINTERNATIONALACCOUNT = 'UnsupportedOperation.InvalidPermissionNonInternationalAccount'
-
 # 指定的地域不支持加密盘。
 UNSUPPORTEDOPERATION_INVALIDREGIONDISKENCRYPT = 'UnsupportedOperation.InvalidRegionDiskEncrypt'
 
@@ -1097,12 +1097,6 @@ UNSUPPORTEDOPERATION_REDHATINSTANCEUNSUPPORTED = 'UnsupportedOperation.RedHatIns
 # 不支持该地域
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
-# 当前用户暂不支持购买预留实例计费。
-UNSUPPORTEDOPERATION_RESERVEDINSTANCEINVISIBLEFORUSER = 'UnsupportedOperation.ReservedInstanceInvisibleForUser'
-
-# 用户预留实例计费配额已达上限。
-UNSUPPORTEDOPERATION_RESERVEDINSTANCEOUTOFQUATA = 'UnsupportedOperation.ReservedInstanceOutofQuata'
-
 # 共享镜像不支持导出。
 UNSUPPORTEDOPERATION_SHAREDIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.SharedImageExportUnsupported'
 
